<?php
	/*
	Plugin Name: jQuery Pin It Button For Images
	Plugin URI: http://www.wordpress.org/
	Description: Highlights images on hover and adds a "Pin It" button over them for easy pinning.
	Author: Marcin Skrzypiec
	Version: 0.5
	Author URI: http://www.wordpress.org/
	*/
	
	if (!empty($_SERVER['SCRIPT_FILENAME']) && 'jquery-pin-it-button-for-images.php' == basename($_SERVER['SCRIPT_FILENAME'])) die ('Stop! Hammer time!'); //Plugin shouldn't be accessed directly
	
	define("JPIBFI_VERSION", "0.5");
	
	if (!class_exists("jQuery_Pin_It_Button_For_Images")) {
		class jQuery_Pin_It_Button_For_Images {
		
			var $admin_options_name = "jptbfi_options";
			var $description_option_values = array ( '1', '2', '3' );
		
			//Constructor
			function jQuery_Pin_It_Button_For_Images() {}
			
			//Returns an array of admin options, updates settings if necessary
			function get_admin_options() {
				$admin_options = array(
					'image_selector'     => 'div.jpibfi_container img',
					'disabled_classes'   => 'nopin;wp-smiley',
					'description_option' => '1',
					'enabled_classes'    => '',
					'compatibility_mode' => $this->description_option_values[0]
				);
				
				$dev_options = get_option( $this->admin_options_name );
				$changes_in_db = count( $admin_options ) != count ( $dev_options ); //if arrays aren't of the same length, changes in db needed
				
				//invalid values need to be corrected and saved in db
				if ( ! empty( $dev_options ) ) {
					foreach ( $dev_options as $key => $option ) {
						switch ($key) {
							case "image_selector":
								$admin_options[$key] = $option;
								break;
							case "disabled_classes":
							case "enabled_classes":
								if ( $this->contains_css_class_names_or_empty( $option ) )
									$admin_options[$key] = $option;
								else
									$changes_in_db = true;
								break;
							case "description_option":
								if ( in_array( $option, $this->description_option_values ) )
									$admin_options[$key] = $option;
								else
									$changes_in_db = true;	
								break;
							case "compatibility_mode":
								if ( strcmp( $option, '0') != 0 && strcmp( $option, '1') != 0 ) //invalid value in database
									$changes_in_db = true;
								else
									$admin_options[$key] = $option;
								break;
						}
					}
				} else {
					$changes_in_db = true;
				}
								
				//if something changed in the database, we need to save it
				if ( $changes_in_db )
					update_option( $this->admin_options_name, $admin_options );
				return $admin_options;
			}
			
			//fire it when activating the plugin
			function init_plugin() {
				$this->get_admin_options();
			}
			
			//Adds all necessary scripts
			function add_plugin_scripts() {
				// Adding my custom js, dependent on jquery
				wp_enqueue_script( 'jquery-pin-it-button-script', plugins_url( '/js/script.js', __FILE__ ), array('jquery'), JPIBFI_VERSION, false );
				// Registering my custom style
				wp_register_style( 'jquery-pin-it-button-style', plugins_url( '/css/style.css', __FILE__ ), array(), JPIBFI_VERSION, 'all' );  
				//Enqueue the style
				wp_enqueue_style( 'jquery-pin-it-button-style');
			}
			
			function add_admin_site_scripts() {
				wp_register_style( 'jquery-pin-it-button-admin-style', plugins_url( '/css/admin.css', __FILE__ ), array(), JPIBFI_VERSION, 'all' );  
				wp_enqueue_style( 'jquery-pin-it-button-admin-style' );
			}
			
			function is_string_css_class_name($class_name) {
				return 1 == preg_match( "/^-?[_a-zA-Z]+[_a-zA-Z0-9-]*$/", $class_name );
			}
			
			function contains_css_class_names_or_empty($str) {
				if ( strlen ($str ) == 0 )
					return true;

				$names = explode( ";", $str );
				$only_css_class_names = true;
				
				foreach ( $names as $name ) {
					if ( false == $this->is_string_css_class_name( $name ) ) {
						$only_css_class_names = false;
						break;
					}
				}
				return $only_css_class_names;
			}
			
			//Prints out the admin page
			function print_admin_page() {
				$dev_options = $this->get_admin_options();
									
				if ( isset( $_POST['update_jQuery_Pin_It_Button_For_Images']) ) {
					$errors = array();
					
					if ( ! $this->contains_css_class_names_or_empty( $_POST['disabled_classes'] ) )
						array_push( $errors, "Disabled classes field not valid");
					
					if ( ! $this->contains_css_class_names_or_empty( $_POST['enabled_classes'] ) )
						array_push( $errors, "Enabled classes field not valid");
					
					if ( ! in_array( $_POST['description_option'], $this->description_option_values ) )
						array_push( $errors, "Description option field not valid");

					if ( 0 == count( $errors ) ) {
						$dev_options['image_selector']     = sanitize_text_field( $_POST['image_selector'] );
						$dev_options['compatibility_mode'] = $_POST['compatibility_mode'] == '1' ? '1' : '0';
						$dev_options['disabled_classes']   = $_POST['disabled_classes'];
						$dev_options['enabled_classes']    = $_POST['enabled_classes'];
						$dev_options['description_option'] = $_POST['description_option'];
						update_option( $this->admin_options_name, $dev_options );
					?>
						<p class="jpibfi-success-message"><?php _e( "Settings Updated.", "jQuery_Pin_It_Button_For_Images" );?></p>
					<?php 
					} else {
						foreach( $errors as $error ) {
							echo "<p class='jpibfi-error-message'>" . $error . "</p>";
						}
					}
				}
				?>
				<div class="wrap">
					<h2>jQuery Pin It Button For Images</h2>
					<form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
						<h3>Plugin settings</h3>
						
						<table class="settings-table">
							<tbody>
								<tr>
									<th scope="row"><label for="image_selector">Image selector</label></th>
									<td>
										<input type="text" size="50" id="image_selector" name="image_selector" value="<?php echo esc_attr( $dev_options['image_selector'] );?>" />
										<p class="description">jQuery selector for all the images that should have the "Pin it" button. Set the value to <b>div.jpibfi_container img</b> if you want the "Pin it" button to appear only on images in content or <b>img</b> to appear on all images on site (including sidebar, header and footer). If you know a thing or two about jQuery, you might use your own selector. <a href="http://api.jquery.com/category/selectors/" target="_blank">Click here</a> to read about jQuery selectors.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="disabled_classes">Disabled classes</label></th>
									<td>
										<textarea rows="3" cols="25" id="disabled_classes" name="disabled_classes"><?php echo esc_attr( $dev_options['disabled_classes'] );?></textarea>
										<p class="description">Pictures with these CSS classes won't show the "Pin it" button. Please separate multiple classes with semicolons. Spaces are not accepted.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="enabled_classes">Enabled classes</label></th>
									<td>
										<textarea rows="3" cols="25" id="enabled_classes" name="enabled_classes"><?php echo $dev_options['enabled_classes'];?></textarea>
										<p class="description">Pictures with these CSS classes will show the "Pin it" button. Please separate multiple classes with semicolons. If this field is empty, images with any (besides disabled ones) classes will show the Pin It button.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label for="description_option">Description source</label></th>
									<td>
										<select id="description_option" name="description_option">
											<option value="1" <?php if ( "1" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>Page title</option>
											<option value="2" <?php if ( "2" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>Page description</option>
											<option value="3" <?php if ( "3" == $dev_options['description_option'] ) echo "selected='selected'"; ?>>Picture title or alt attributes</option>
										</select>
										<p class="description">From where the Pinterest message should be taken.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"><label> IE7 Compatibility mode</label></th>
									<td>
										<input type="checkbox" id="compatibility_mode" name="compatibility_mode" <?php echo "1" == $dev_options['compatibility_mode'] ? "checked='checked'" : "";?>" value="1" /><label for="compatibility_mode"> Compatibility mode</label>
										<p class="description">Check this if you want the plugin to work properly on IE7. Without this it doesn't highlight images on IE7.</p>
									</td>
								</tr>
								<tr>
									<th scope="row"></th>
									<td>
										<input type="submit" style="padding:7px;float:right;" name="update_jQuery_Pin_It_Button_For_Images" value="<?php _e( 'Update Settings', 'jQuery_Pin_It_Button_For_Images' ) ?>" />
									</td>
								</tr>
							</tbody>
						</table>
					</form>
				 </div>
				<?php
			}//End function print_admin_page()
			
			function print_admin_page_action() {
				$page = add_options_page( 'jQuery Pin It Button For Images', 'jQuery Pin It Button For Images', 9, basename( __FILE__ ), array( $this, 'print_admin_page' ) );
				add_action( 'admin_print_styles-' . $page, array($this, 'add_admin_site_scripts'));
			}
			
			function jptbfi_instance_action() {
				$dev_options = $this->get_admin_options();
				?>
				<script type="text/javascript">
					jQuery(document).ready(function($) {
						$('.jpibfi').parent('div').addClass('jpibfi_container');
						$('<?php echo $dev_options['image_selector'];?>').pinit({disabled_classes:'<?php echo $dev_options['disabled_classes'];?>', 
							description_option:'<?php echo $dev_options['description_option'];?>'<?php if ( $dev_options['enabled_classes'] ) echo ", enabled_classes:'".$dev_options['enabled_classes']."'";?>});
					});
				</script>
				<?php
			}
			
			function print_header_style_action() {
				$dev_options = $this->get_admin_options();
				?>
				<style type="text/css">
				.pinit .pinit-overlay {
				<?php
				if ( $dev_options['compatibility_mode'] == '0' )
					echo 'background-color: rgba(255,255,255,0.5);';
				else
					echo "background: url('" . plugins_url('/images/point-five.png', __FILE__) . "') repeat;";
				?>
				}</style>
				<?php
			}
			
			function print_hidden_field_script($content) {
				return "<input class='jpibfi' type='hidden' />" . $content; 
			}
			
			function plugin_settings_filter($links) { 
			  $settings_link = '<a href="options-general.php?page=jquery-pin-it-button-for-images.php">Settings</a>'; 
			  array_unshift( $links, $settings_link ); 
			  return $links; 
			}
		}
	} //End Class jQuery_Pin_It_Button_For_Images
	
	if ( class_exists("jQuery_Pin_It_Button_For_Images") ) {
		$jptbfi_instance = new jQuery_Pin_It_Button_For_Images();
	}

	//Actions and Filters	
	if ( isset($jptbfi_instance) ) {
		//Actions
		add_action( 'wp_enqueue_scripts', array( &$jptbfi_instance, 'add_plugin_scripts' ) );
		add_action( 'activate_jquery-pin-it-button-for-images/jquery-pin-it-button-for-images.php',  array( &$jptbfi_instance, 'init_plugin' ) );
		add_action( 'admin_menu', array( &$jptbfi_instance, 'print_admin_page_action' ) );
		add_action( 'wp_footer', array( &$jptbfi_instance, 'jptbfi_instance_action' ) );
		add_action( 'wp_head', array( &$jptbfi_instance, 'print_header_style_action' ) ); 
		
		//Filters
		$plugin = plugin_basename( __FILE__ ); 
		add_filter( "plugin_action_links_$plugin", array( &$jptbfi_instance, 'plugin_settings_filter' ) );
		add_filter( "the_content", array( &$jptbfi_instance, 'print_hidden_field_script' ) );
	}

?>